@@ -80,7 +80,8 @@ class Test_Open_FilePicker(object):
         QtWidgets.QApplication.processEvents()
         QtWidgets.QApplication.processEvents()
         self.window.action()
-        assert u"./foo/foo.txt" in self.window.file_list_items
+        _file_names = [name.keys()[0] for name in self.window.file_list_items]
+        assert u"./foo/foo.txt" in _file_names
         assert len(self.window.file_list_items) == 1
 
     def test_showname_close(self):
@@ -91,7 +92,8 @@ class Test_Open_FilePicker(object):
     def test_showname_on_filename(self):
         self.window.show_name()
         filename = u"./example.csv"
-        all_items = self.window.dir_list_items + self.window.file_list_items
+        _file_names = [name.keys()[0] for name in self.window.file_list_items]
+        all_items = self.window.dir_list_items + _file_names
         index = all_items.index(filename)
         self.window.ui_FileList.selectRow(index)
         QtWidgets.QApplication.processEvents()
@@ -125,10 +127,12 @@ class Test_Open_FilePicker(object):
         assert self.window.filename == u"example.txt"
 
     def test_subdirectory(self):
-        index = self.window.dir_list_items.index(u'./bar')
+        _folder_names = [name.keys()[0] for name in self.window.dir_list_items]
+        index = _folder_names.index(u'./bar')
         self.window.onCellDoubleClicked(index, 0)
         QtWidgets.QApplication.processEvents()
-        assert self.window.file_list_items[0] == "./bar/foo.txt"
+        _file_names = [name.keys()[0] for name in self.window.file_list_items]
+        assert _file_names[0] == "./bar/foo.txt"
         self.window.onCellClicked(0, 0)
         QtWidgets.QApplication.processEvents()
         self.window.action()
@@ -140,8 +144,9 @@ class Test_Open_FilePicker(object):
         self.window.onCellDoubleClicked(0, 0)
         QtWidgets.QApplication.processEvents()
         self.window.close()
+        _file_names = [name.keys()[0] for name in self.window.file_list_items]
         assert u"bar" in self.window.ui_DirList.currentText()
-        assert u"./bar/foo.txt" in self.window.file_list_items
+        assert u"./bar/foo.txt" in _file_names
 
 
 class Test_Save_FilePicker(object):
@@ -211,7 +216,7 @@ class Test_Save_FilePicker(object):
         index = sorted(SUB_DIRS).index(u'testdata/empty')
         self.window.ui_FileList.selectRow(index)
         QtWidgets.QApplication.processEvents()
-        self.window.onCellClicked(index, 0)
+        self.window.onCellDoubleClicked(index, 0)
         QtWidgets.QApplication.processEvents()
         self.window.selection_directory()
         self.window.ui_SelectedName.setText(u"example.txt")
@@ -219,7 +224,7 @@ class Test_Save_FilePicker(object):
         self.window.action()
         QtWidgets.QApplication.processEvents()
         self.window.close()
-        assert self.window.wparm.value == u'./empty'
+        assert self.window.wparm.value.keys()[0] == u"./empty"
         assert u"example.txt" in self.window.filename
 
     @mock.patch("fslib.fs_filepicker.QtWidgets.QInputDialog.getText",
@@ -233,16 +238,18 @@ class Test_Save_FilePicker(object):
         self.window.make_dir()
         QtWidgets.QApplication.processEvents()
         self.window.close()
-        assert u'./empty/exampledir' in self.window.dir_list_items
+        _folder_names = [name.keys()[0] for name in self.window.dir_list_items]
+        assert u'./empty/exampledir' in _folder_names
 
     @mock.patch("fslib.fs_filepicker.QtWidgets.QInputDialog.getText",
                 return_value=(u"thisexampledir", True))
     def test_history_makedir(self, mocktext):
-        index = self.window.dir_list_items.index(u'./empty')
+        _folder_names = [name.keys()[0] for name in self.window.dir_list_items]
+        index = _folder_names.index(u'./empty')
         self.window.onCellDoubleClicked(index, 0)
         QtWidgets.QApplication.processEvents()
         self.window.history_previous()
-        index = self.window.dir_list_items.index(u'./bar')
+        index = _folder_names.index(u'./bar')
         self.window.onCellDoubleClicked(index, 0)
         QtWidgets.QApplication.processEvents()
         self.window.history_previous()
@@ -250,6 +257,7 @@ class Test_Save_FilePicker(object):
         QtWidgets.QApplication.processEvents()
         self.window.make_dir()
         QtWidgets.QApplication.processEvents()
+        _folder_names = [name.keys()[0] for name in self.window.dir_list_items]
         self.window.close()
-        assert u'./empty/thisexampledir' in self.window.dir_list_items
+        assert u'./empty/thisexampledir' in _folder_names
         assert self.window.last_dir_index == 1
