@@ -29,6 +29,7 @@ import argparse
 import fs
 import humanfriendly
 from PyQt5 import QtWidgets, QtCore
+from PyQt5.QtWidgets import QAbstractItemView
 from PyQt5.QtGui import QIcon
 from fslib import ui_filepicker, __version__
 from fslib.utils import match_extension, WidgetImageText, WidgetText
@@ -79,6 +80,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.ui_fs.clicked.connect(self.fs_button)
         self.ui_FileList.cellClicked.connect(self.onCellClicked)
         self.ui_FileList.cellDoubleClicked.connect(self.onCellDoubleClicked)
+        self.ui_FileList.setSelectionBehavior(QAbstractItemView.SelectRows)
         self.ui_DirList.currentIndexChanged.connect(self.selection_directory)
 
     def button_icons(self):
@@ -108,20 +110,26 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         Action home button
         """
         self.active_url = self.fs_home_url
-        self.directory_history = []
-        if self.fs:
-            self.fs.close()
-        if self.wparm is not None:
-            self.wparm = None
-        self.fs = fs.open_fs(self.active_url)
-        self.browse_folder()
-        self.selection_directory()
+        self.select_fs()
+
+    def root_button(self):
+        """
+        Action root button
+        """
+        self.active_url = self.fs_root_url
+        self.select_fs()
 
     def fs_button(self):
         """
         Action fs button
         """
         self.active_url = self.fs_url
+        self.select_fs()
+
+    def select_fs(self):
+        """
+        loads the selected fs to the file list ui
+        """
         self.directory_history = []
         if self.fs:
             self.fs.close()
@@ -136,20 +144,6 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.browse_folder()
         self.selection_directory()
 
-    def root_button(self):
-        """
-        Action root button
-        """
-        self.active_url = self.fs_root_url
-        self.directory_history = []
-        if self.fs:
-            self.fs.close()
-        if self.wparm is not None:
-            self.wparm = None
-        self.fs = fs.open_fs(self.active_url)
-        self.browse_folder()
-        self.selection_directory()
-
     def action_buttons(self):
         """
         Open / Save button action connect
@@ -228,11 +222,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
                 _mod_time = info.modified.strftime(u"%Y-%m-%d %H:%M:%S")
             except TypeError:
                 _mod_time = u""
-            try:
-                _size = unicode(humanfriendly.format_size(info.size))
-            except (AttributeError, TypeError):
-                _size = u""
-
+            _size = u"Folder"
             self.ui_FileList.setCellWidget(index, 0, WidgetImageText(fs.path.basename(item.keys()[0]),
                                                                      self.dir_icon, item))
             self.ui_FileList.setCellWidget(index, 1, WidgetText(_size))
@@ -288,7 +278,6 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
                 if "folder" in self.wparm.img:
                     _folder_names = [name.keys()[0] for name in self.dir_list_items]
                     self.directory_history.append(self.wparm.value.keys()[0])
-                    index = _folder_names.index(self.wparm.value.keys()[0])
                     self.browse_folder(subdir=self.wparm.value.keys()[0])
         except AttributeError:
             pass
@@ -367,7 +356,6 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         """
         new_dir_name, ok = QtWidgets.QInputDialog.getText(self, u"New Folder", u"Enter a new folder name:",
                                                           QtWidgets.QLineEdit.Normal, "")
-
         if ok:
             if self.wparm is None:
                 dirname = u''
@@ -375,7 +363,10 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
                 dirname = self.selected_dir
             new_dir = fs.path.combine(dirname, new_dir_name)
             if not self.fs.isdir(new_dir):
-                self.fs.makedir(new_dir)
+                try:
+                    self.fs.makedir(new_dir)
+                except fs.errors.ResourceNotFound:
+                    logging.error(u"Can't create {}".format(new_dir))
                 self.last_dir_index = list(reversed(self.directory_history)).index(self.selected_dir)
                 self.browse_folder(subdir=self.selected_dir)
             else:
@@ -480,7 +471,6 @@ def main():
     parser.add_argument("-u", "--fs_url", help="fs url to filesystem", default=u"~/")
     parser.add_argument("-f", "--file_pattern", help="file pattern", default=u"*.*")
     parser.add_argument("-t", "--title", help="title of window", default=u'FS File Picker')
-
     args = parser.parse_args()
     if args.version:
         print("***********************************************************************")
